.. _bluegraph_backends_stellargraph_ref:

`stellargraph` package
-----------------------

Reference page for the `bluegraph.backends.stellargraph` package.  All the interfaces below are also available as `bluegraph.backends.stellargraph.<interface>` (for example, :code:`from bluegraph.backends.stellargraph import StellarGraphNodeEmbedder`).




Node embedding
^^^^^^^^^^^^^^

.. automodule:: bluegraph.backends.stellargraph.embed.embedders
	:members:
